import core.BO.integracao
import core.comunicacao.mensagem.models
import unicodedata


class Mensagem(core.BO.integracao.Integracao):
    """
    :Nome da classe/função: Email
    :descrição: Classe para envio de mensagem
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    def __init__(self, destinatario=None, request=None, modulo=None):
        url = None
        headers = None
        super(Mensagem, self).__init__(url=url, headers=headers, request=request, servico='nvoip', modulo=modulo)

        self.conteudo = None
        self.destinatario = destinatario
        self.mensagem = None

    def salvar_mensagem(self):
        """
        :Nome da classe/função: salvar_mensagem
        :descrição: Classe para salvar log de mensagem
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :status: Status de log
        """
        try:
            novo_log = core.comunicacao.mensagem.models.MensagemLog(
                mensagem_id=self.mensagem,
                destinatario=self.destinatario,
                retorno=self.response
            )
            novo_log.save()
            return True
        except:
            return False

    def enviar(self):
        """
         :Nome da classe/função: enviar
        :descrição: Classe para enviar mensagem
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return:  Status de envio
        """
        try:
            self.body = {
                "celular": ''.join(c for c in self.destinatario if c.isdigit()),
                "msg": unicodedata.normalize('NFD', self.conteudo[:160]).encode('ASCII', 'ignore').decode('utf-8')
            }
            self.post()
            self.salvar_mensagem()
            return True
        except:
            return False

    def carregar(self):
        """
        :Nome da classe/função: carregar
        :descrição: Classe para carregar a mensagem baseada no seu tipo
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Status de carregar
        """
        try:
            mensagem_info = core.comunicacao.mensagem.models.Mensagem.objects.ativos().filter(nome=self.mensagem).first()
            if mensagem_info is None:
                return False
            self.conteudo = mensagem_info.conteudo
            return True
        except:
            pass
        return False

    @property
    def conteudo(self):
        return self.__conteudo

    @conteudo.setter
    def conteudo(self, value):
        self.__conteudo = value

    @conteudo.deleter
    def conteudo(self):
        del self.__conteudo

    @property
    def destinatario(self):
        return self.__destinatario

    @destinatario.setter
    def destinatario(self, value):
        self.__destinatario = value

    @destinatario.deleter
    def destinatario(self):
        del self.__destinatario

    @property
    def mensagem(self):
        return self.__mensagem

    @mensagem.setter
    def mensagem(self, value):
        self.__mensagem = value

    @mensagem.deleter
    def mensagem(self):
        del self.__mensagem




from django.contrib import admin
import core.filial.models
# Register your models here.


class FilialAdmin(admin.ModelAdmin):
    ordering = ['cd_filial']
    list_display = ['cd_filial', 'nome']


class ServicoAdmin(admin.ModelAdmin):
    list_display = ['nome', 'descricao']


class FilialServicoAdmin(admin.ModelAdmin):
    list_display = ['cd_filial', 'servico']


class FilialHoraFuncionamentoAdmin(admin.ModelAdmin):
    list_display = ['cd_filial', 'cd_hr_util_inicio', 'cd_hr_util_fim', 'cd_hr_sab_inicio',
                    'cd_hr_sab_fim', 'cd_hr_dom_inicio', 'cd_hr_dom_fim']


admin.site.register(core.filial.models.Filial, FilialAdmin)
admin.site.register(core.filial.models.Servico, ServicoAdmin)
admin.site.register(core.filial.models.FilialServico, FilialServicoAdmin)
admin.site.register(core.filial.models.FilialHoraFuncionamento, FilialHoraFuncionamentoAdmin)



# Generated by Django 2.1.7 on 2020-08-17 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('e_mail', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='email',
            name='assunto',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='conteudo',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='endereco',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endereco_email', to='e_mail.EmailEndereco'),
        ),
        migrations.AlterField(
            model_name='email',
            name='nm_descritivo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='email',
            name='variaveis',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='email',
            field=models.EmailField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='host',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='password',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emailendereco',
            name='port',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='destinatario',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='email',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='e_mail.Email'),
        ),
        migrations.AlterField(
            model_name='emaillog',
            name='retorno',
            field=models.TextField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-20 13:03

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0018_auto_20200806_1830'),
        ('filial', '0021_auto_20200818_1832'),
    ]

    operations = [
        migrations.AddField(
            model_name='area',
            name='responsavel',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='funcionario.Funcionario'),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='responsavel',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='funcionario.Funcionario'),
        ),
    ]



from django.contrib import admin
import core.produto.models
# Register your models here.


class ProdutoAdmin(admin.ModelAdmin):
    list_display = ['cd_produto', 'nome', 'nm_ecommerce', 'nm_url_ecommerce', 'is_ecommerce']
    ordering = ['cd_produto']


class PrecoListaAdmin(admin.ModelAdmin):
    list_display = ['nome', 'dat_ini', 'dat_fim']


class ProdutoPrecoAdmin(admin.ModelAdmin):
    list_display = ['produto', 'precolista']


admin.site.register(core.produto.models.Produto, ProdutoAdmin)
admin.site.register(core.produto.models.ProdutoImagem)
admin.site.register(core.produto.models.Marca)
admin.site.register(core.produto.models.Categoria)

admin.site.register(core.produto.models.PrecoLista, PrecoListaAdmin)
admin.site.register(core.produto.models.ProdutoPreco, ProdutoPrecoAdmin)


# Generated by Django 2.1.7 on 2020-08-13 04:21

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
    ]

    operations = [
        migrations.CreateModel(
            name='Email',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('assunto', models.CharField(max_length=200, null=True)),
                ('conteudo', models.TextField(null=True)),
                ('variaveis', models.TextField(null=True)),
            ],
            options={
                'db_table': 'comunicacao_email',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='EmailEndereco',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('email', models.EmailField(max_length=200, null=True)),
                ('port', models.IntegerField(null=True)),
                ('host', models.CharField(max_length=200, null=True)),
                ('password', models.CharField(max_length=200, null=True)),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emailendereco_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'comunicacao_email_endereco',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='EmailLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('destinatario', models.CharField(max_length=200, null=True)),
                ('retorno', models.TextField(null=True)),
                ('email', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='e_mail.Email')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_emaillog_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'comunicacao_email_log',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AddField(
            model_name='email',
            name='endereco',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='endereco_email', to='e_mail.EmailEndereco'),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='email',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='e_mail_email_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-09 21:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0028_auto_20200806_2317'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cartao',
            name='cartao_token',
        ),
        migrations.AddField(
            model_name='cartao',
            name='password',
            field=models.CharField(max_length=50, null=True),
        ),
    ]



from django.db import models
import core.models
# Create your models here.


class EmailEndereco(core.models.Log):
    """
    :Nome da classe/função: EmailEndereco
    :descrição: Classe de endereços de e-mail
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    email = models.EmailField(max_length=200, null=True, blank=True)
    port = models.IntegerField(null=True, blank=True)
    host = models.CharField(max_length=200, null=True, blank=True)
    password = models.CharField(max_length=200, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'comunicacao_email_endereco'

    def __str__(self):
        return self.email


class Email(core.models.Log):
    """
    :Nome da classe/função: Email
    :descrição: Classe de e-mail
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True, blank=True)
    assunto = models.CharField(max_length=200, null=True, blank=True)
    conteudo = models.TextField(null=True, blank=True)
    endereco = models.ForeignKey('EmailEndereco', on_delete=models.DO_NOTHING, null=True, blank=True, related_name='endereco_email')
    variaveis = models.TextField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'comunicacao_email'

    def __str__(self):
        return self.nm_descritivo


class EmailLog(core.models.Log):
    """
    :Nome da classe/função: EmailLog
    :descrição: Classe de log de e-mail
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    email = models.ForeignKey('Email', on_delete=models.DO_NOTHING, null=True, blank=True)
    destinatario = models.CharField(max_length=200, null=True, blank=True)
    retorno = models.TextField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'comunicacao_email_log'



# Generated by Django 2.1.7 on 2020-08-21 13:53

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
        ('cliente', '0034_auto_20200821_1053'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='adquirente',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='cliente_cartao_adquirente', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('adquirente_codigo'), 'tipo': compositefk.fields.LocalFieldValue('adquirente_tipo')}),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_codigo',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='adquirente_tipo',
            field=models.CharField(default='CLIENTE.CARTAO.ADQUIRENTE', max_length=200, null=True),
        ),
    ]



import core.comunicacao.e_mail.models
import core.util.criptografia
import smtplib
from email.mime.multipart import MIMEMultipart
from email.mime.text import MIMEText
import core.comunicacao.e_mail.models
import core.comunicacao.mensagem.models


class Email:
    """
    :Nome da classe/função: Email
    :descrição: Classe para envio de e-mail
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    def __init__(self, destinatario=None):
        self.email = None

        self.endereco = None
        self.password = None
        self.host = None
        self.port = None

        self.assunto = None
        self.conteudo = None

        self.destinatario = destinatario

        self.retorno = None

    def carregar(self):
        """
        :Nome da classe/função: carregar
        :descrição: Função que carrega o e-mail baseado no tipo
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Status de carregar
        """
        try:
            email_info = core.comunicacao.e_mail.models.Email.objects.ativos().filter(nome=self.email).first()
            if email_info is None:
                return False

            self.endereco = email_info.endereco.email
            self.password = self.descriptografar_senha(email_info.endereco.password)
            self.host = email_info.endereco.host
            self.port = email_info.endereco.port

            self.assunto = email_info.assunto
            self.conteudo = email_info.conteudo
            return True
        except:
            pass
        return False

    def criptografar_senha(self, senha):
        """
        :Nome da classe/função: criptografar_senha
        :descrição: Função para criptografar senha do email
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Token da senha criptografado
        """
        senha_token = core.util.criptografia.password_encrypt(message=senha, password='A3DF750D4245BA42B14EABCE7DDC3ACFDF4B9C30441DC3B8D8DF2C9A3D18FB6B')
        return senha_token.decode()

    def descriptografar_senha(self, senha_token):
        """
        :Nome da classe/função: descriptografar_senha
        :descrição: Função para descriptografar senha do email
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Senha descriptografada
        """
        senha = core.util.criptografia.password_decrypt(token=senha_token.encode(), password='A3DF750D4245BA42B14EABCE7DDC3ACFDF4B9C30441DC3B8D8DF2C9A3D18FB6B').decode()
        return senha

    def salvar_email(self):
        """
        :Nome da classe/função: salvar
        :descrição: Função para salvar log de envio de e-mail
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Status de log
        """
        try:
            novo_log = core.comunicacao.e_mail.models.EmailLog(
                email_id=self.email,
                destinatario=self.destinatario,
                retorno=self.retorno
            )
            novo_log.save()
            return True
        except:
            return False

    def enviar(self):
        """
        :Nome da classe/função: enviar
        :descrição: Função para enviar o e-mail
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Status de envio
        """
        try:
            s = smtplib.SMTP(host=self.host, port=self.port)
            s.starttls()
            s.login(self.endereco, self.password)
            msg = MIMEMultipart()
            msg['From'] = self.endereco
            msg['To'] = self.destinatario
            msg['Subject'] = self.assunto
            msg.attach(MIMEText(self.conteudo, 'html'))
            self.retorno = s.send_message(msg)
            self.salvar_email()
            s.quit()
            return True
        except:
            return False

    @property
    def email(self):
        return self.__email

    @email.setter
    def email(self, value):
        self.__email = value

    @email.deleter
    def email(self):
        del self.__email

    @property
    def endereco(self):
        return self.__endereco

    @endereco.setter
    def endereco(self, value):
        self.__endereco = value

    @endereco.deleter
    def endereco(self):
        del self.__endereco

    @property
    def password(self):
        return self.__password

    @password.setter
    def password(self, value):
        self.__password = value

    @password.deleter
    def password(self):
        del self.__password

    @property
    def host(self):
        return self.__host

    @host.setter
    def host(self, value):
        self.__host = value

    @host.deleter
    def host(self):
        del self.__host

    @property
    def port(self):
        return self.__port

    @port.setter
    def port(self, value):
        self.__port = value

    @port.deleter
    def port(self):
        del self.__port

    @property
    def assunto(self):
        return self.__assunto

    @assunto.setter
    def assunto(self, value):
        self.__assunto = value

    @assunto.deleter
    def assunto(self):
        del self.__assunto

    @property
    def conteudo(self):
        return self.__conteudo

    @conteudo.setter
    def conteudo(self, value):
        self.__conteudo = value

    @conteudo.deleter
    def conteudo(self):
        del self.__conteudo

    @property
    def destinatario(self):
        return self.__destinatario

    @destinatario.setter
    def destinatario(self, value):
        self.__destinatario = value

    @destinatario.deleter
    def destinatario(self):
        del self.__destinatario

    @property
    def retorno(self):
        return self.__retorno

    @retorno.setter
    def retorno(self, value):
        self.__retorno = value

    @retorno.deleter
    def retorno(self):
        del self.__retorno



def numero_string_br(valor=0, casas_decimais=2):
    """
    :Nome da classe/função: numero_string_br
    :descrição: Função para formatar numeros em string no formato brasileiro
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    :param valor:
    :param casas_decimais:
    :return:
    """
    try:
        return format(valor, '.{}f'.format(str(casas_decimais))).replace('.', '*').replace(',', '.').replace('*', ',')
    except:
        return '0,00'



# Generated by Django 2.1.7 on 2020-08-21 13:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('funcionario', '0018_auto_20200806_1830'),
    ]

    operations = [
        migrations.AddField(
            model_name='funcionario',
            name='rg_form',
            field=models.CharField(max_length=15, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-18 21:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('filial', '0019_auto_20200818_1826'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='filialservico',
            name='cd_filial',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='filialservico',
            name='servico',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_delete',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_edicao',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='origem_insercao',
        ),
        migrations.RemoveField(
            model_name='servico',
            name='tipo',
        ),
        migrations.RemoveField(
            model_name='filial',
            name='servicos',
        ),
        migrations.DeleteModel(
            name='FilialServico',
        ),
        migrations.DeleteModel(
            name='Servico',
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-18 21:26

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
        ('filial', '0018_auto_20200806_1830'),
    ]

    operations = [
        migrations.CreateModel(
            name='Area',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('cd_area', models.IntegerField(primary_key=True, serialize=False)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('nome_completo', models.CharField(max_length=200, null=True)),
                ('tipo_codigo', models.CharField(max_length=200, null=True)),
                ('tipo_tipo', models.CharField(default='FILIAL.AREA', max_length=200, null=True)),
                ('area_pai', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Area')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_area_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_area_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_area_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('tipo', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_area', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')})),
            ],
            options={
                'db_table': 'filial_area',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='FilialArea',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('dat_ini', models.DateField(null=True)),
                ('dat_fim', models.DateField(null=True)),
                ('area', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Area')),
            ],
            options={
                'db_table': 'filial_filialarea',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.RemoveField(
            model_name='filial',
            name='telefone',
        ),
        migrations.AddField(
            model_name='filial',
            name='celular_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='celular_completo_form',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='celular_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='celular_numero',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='dat_abertura',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='dat_fechamento',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='ip_acesso',
            field=models.CharField(max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='is_loja',
            field=models.BooleanField(default=True, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='telefone_completo',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='telefone_completo_form',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='telefone_ddd',
            field=models.CharField(max_length=3, null=True),
        ),
        migrations.AddField(
            model_name='filial',
            name='telefone_numero',
            field=models.CharField(max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='filialservico',
            name='informacao',
            field=models.CharField(max_length=500, null=True),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='cd_filial',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial'),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialarea_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialarea_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='filialarea',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='filial_filialarea_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='filial',
            name='area',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='area_atual', to='filial.Area'),
        ),
        migrations.AddField(
            model_name='filial',
            name='areas',
            field=models.ManyToManyField(through='filial.FilialArea', to='filial.Area'),
        ),
    ]



from types import MethodType
from django.test.runner import DiscoverRunner
from django.db import connections


def prepare_database(self):
    """
    :Nome da classe/função: prepare_database
    :descrição: Função que conecta a uma database e executa o script para ser possível usar os tests do django
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    :param self: Conexão da database
    :return:
    """
    self.connect()
    self.connection.cursor().execute("""
    CREATE SCHEMA log;
    GRANT ALL ON SCHEMA log TO voai;
    GRANT ALL ON SCHEMA log TO cliente;
    """)


class PostgresSchemaTestRunner(DiscoverRunner):
    """
    :Nome da classe/função: PostgresSchemaTestRunner
    :descrição: Classe chamada na hora de gerar os tests do django e preparar a database
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    def setup_databases(self, **kwargs):
        """
        :Nome da classe/função: setup_databases
        :descrição: Função que constrói o database para tests
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :param kwargs:
        :return: Database construida
        """
        for connection_name in connections:
            connection = connections[connection_name]
            connection.prepare_database = MethodType(prepare_database, connection)
        return super().setup_databases(**kwargs)


# Generated by Django 2.1.7 on 2020-08-10 01:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0031_auto_20200809_2234'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cartao',
            name='password',
            field=models.CharField(max_length=200, null=True),
        ),
    ]



from django.db import models
import core.usr.models
import core.models


# Create your models here.
class ApiLogin(core.usr.models.Profile):
    """
    :Nome da classe/função: ApiLogin
    :descrição: Classe de login para usuários de API
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'api_login'



from django.db import models
import core.models


# Create your models here.
class Mensagem(core.models.Log):
    """
    :Nome da classe/função: Mensagem
    :descrição: Classe de tipos de mensagens
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True, blank=True)
    conteudo = models.TextField(null=True, blank=True)
    variaveis = models.TextField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'comunicacao_mensagem'

    def __str__(self):
        return self.nm_descritivo


class MensagemLog(core.models.Log):
    """
    :Nome da classe/função: MensagemLog
    :descrição: Classe de log de mensagens
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    mensagem = models.ForeignKey('Mensagem', on_delete=models.DO_NOTHING, null=True, blank=True)
    destinatario = models.CharField(max_length=200, null=True, blank=True)
    retorno = models.TextField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'comunicacao_mensagem_log'



from django.contrib import admin
import core.comunicacao.e_mail.models
# Register your models here.


class EmailAdmin(admin.ModelAdmin):
    list_display = ['nm_descritivo', 'endereco']


admin.site.register(core.comunicacao.e_mail.models.EmailEndereco)

admin.site.register(core.comunicacao.e_mail.models.Email)


# Generated by Django 2.1.7 on 2020-08-21 13:52

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
        ('auth', '0009_alter_user_last_name_max_length'),
    ]

    operations = [
        migrations.CreateModel(
            name='ApiLogin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('password', models.CharField(max_length=128, verbose_name='password')),
                ('last_login', models.DateTimeField(blank=True, null=True, verbose_name='last login')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(blank=True, null=True)),
                ('usr_insercao', models.IntegerField(blank=True, null=True)),
                ('usr_edicao', models.IntegerField(blank=True, null=True)),
                ('usr_delete', models.IntegerField(blank=True, null=True)),
                ('origem_insercao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(blank=True, max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(blank=True, default='USR.PROFILE', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('username', models.CharField(max_length=200, unique=True)),
                ('is_staff', models.BooleanField(default=False, null=True)),
                ('tipo_codigo', models.CharField(max_length=200, null=True)),
                ('tipo_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('origem_codigo', models.CharField(max_length=200, null=True)),
                ('origem_tipo', models.CharField(default='USR.PROFILE', max_length=200, null=True)),
                ('is_superuser', models.BooleanField(default=False, help_text='Designates that this user has all permissions without explicitly assigning them.', verbose_name='superuser status')),
                ('groups', models.ManyToManyField(blank=True, help_text='The groups this user belongs to. A user will get all permissions granted to each of their groups.', related_name='api_apilogin_user_set', related_query_name='user', to='auth.Group', verbose_name='groups')),
                ('origem', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='api_apilogin_origem', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_tipo')})),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='api_apilogin_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='api_apilogin_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='api_apilogin_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('tipo', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='api_apilogin_tipo', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('tipo_codigo'), 'tipo': compositefk.fields.LocalFieldValue('tipo_tipo')})),
                ('user_permissions', models.ManyToManyField(blank=True, help_text='Specific permissions for this user.', related_name='api_apilogin_user_set', related_query_name='user', to='auth.Permission', verbose_name='user permissions')),
            ],
            options={
                'db_table': 'api_login',
                'abstract': False,
                'managed': True,
            },
        ),
    ]



# Generated by Django 2.1.7 on 2020-07-10 18:20

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Grupo',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nivel', models.IntegerField(null=True)),
                ('nome', models.CharField(max_length=200, primary_key=True, serialize=False)),
                ('nm_descritivo', models.CharField(max_length=200, null=True)),
                ('descricao', models.CharField(max_length=500, null=True)),
                ('grupo_pai', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupo_grupo_pai', to='usr.Grupo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupo_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupo_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupo_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
            ],
            options={
                'db_table': 'usr_grupo',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='GrupoUser',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('usr_id', models.IntegerField(null=True)),
                ('usr_codigo', models.CharField(max_length=200, null=True)),
                ('usr_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('grupo', models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='usr.Grupo')),
                ('origem_delete', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupouser_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')})),
                ('origem_edicao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupouser_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')})),
                ('origem_insercao', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupouser_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')})),
                ('usr', compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='usr_grupouser_usr', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('usr_codigo'), 'tipo': compositefk.fields.LocalFieldValue('usr_tipo')})),
            ],
            options={
                'db_table': 'usr_grupouser',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
    ]



from django.contrib.staticfiles.storage import ManifestStaticFilesStorage


class ForgivingManifestStaticFilesStorage(ManifestStaticFilesStorage):
    """
    :Nome da classe/função: ForgivingManifestStaticFilesStorage
    :descrição: Classe feita para atualizar os arquivos com hash para não gerar cache no collectstatic
    :Criação: Juan Sanguino - 17/08/2020
    :Edições:
    """
    manifest_strict = False

    def hashed_name(self, name, content=None, filename=None):
        """
        :Nome da classe/função: hashed_name
        :descrição: Função da classe que gera os hashs para salvar os arquivos
        :Criação: Juan Sanguino - 17/08/2020
        :Edições:
        :param name: Nome base para construir a hash
        :param content: Conteúdo do arquivo
        :param filename: Nome do arquivo
        :return: Arquivo processado
        """
        try:
            result = super().hashed_name(name, content, filename)
        except ValueError:
            # When the fille is missing, let's forgive and ignore that.
            result = name
        return result



# Generated by Django 2.1.7 on 2020-08-24 18:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0017_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='tipo',
            name='codigo',
            field=models.CharField(max_length=200, null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-17 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('mensagem', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='mensagem',
            name='conteudo',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='mensagem',
            name='nm_descritivo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='mensagem',
            name='variaveis',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='mensagemlog',
            name='destinatario',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='mensagemlog',
            name='mensagem',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='mensagem.Mensagem'),
        ),
        migrations.AlterField(
            model_name='mensagemlog',
            name='retorno',
            field=models.TextField(blank=True, null=True),
        ),
    ]



from django.db import models
import core.models


# Create your models here.
class Produto(core.models.Log):
    """
    :Nome da classe/função: Produto
    :descrição: Classe de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    cd_produto = models.IntegerField(primary_key=True)
    cd_externo = models.IntegerField(null=True, blank=True)

    nome = models.CharField(max_length=200, null=True, blank=True)
    descricao = models.TextField(null=True, blank=True)

    marca = models.ForeignKey('produto.Marca', on_delete=models.DO_NOTHING, related_name='marca', null=True, blank=True)
    tipo_produto = models.ForeignKey('produto.Tipo', on_delete=models.DO_NOTHING, null=True, blank=True)
    fabricante = models.ForeignKey('fornecedor.Fabricante', on_delete=models.DO_NOTHING, null=True, blank=True)

    imagem = models.FileField(upload_to="produtos", default='produtos/caixa-nissei.jpg', null=True, blank=True)

    produto_pai = models.ForeignKey('self', models.DO_NOTHING, null=True, blank=True)

    is_ecommerce = models.BooleanField(default=True, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=200, null=True, blank=True)
    nm_ecommerce = models.CharField(max_length=200, null=True, blank=True)
    descricao_ecommerce = models.TextField(null=True, blank=True)
    altura_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)
    largura_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)
    profundidade_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)
    peso_ecommerce = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)
    qtd_min_venda_ecommerce = models.IntegerField(null=True, blank=True, default=1)
    qtd_max_venda_ecommerce = models.IntegerField(null=True, blank=True)

    is_retencao_receita = models.BooleanField(default=False, null=True, blank=True)
    is_venda_controlada = models.BooleanField(default=False, null=True, blank=True)
    is_pbm = models.BooleanField(default=False, null=True, blank=True)

    categoria_principal = models.ForeignKey('produto.Categoria', on_delete=models.DO_NOTHING, null=True, blank=True, related_name='categoria_principal')

    grupo = models.ManyToManyField('produto.Grupo', through='produto.ProdutoGrupo', through_fields=('produto', 'grupo'))
    categoria = models.ManyToManyField('produto.Categoria', through='produto.ProdutoCategoria', through_fields=('produto', 'categoria'))
    kit = models.ManyToManyField('produto.Kit', through='produto.ProdutoKit', through_fields=('produto', 'kit'))
    bula = models.ManyToManyField('produto.Bula', through='produto.ProdutoBula', through_fields=('produto', 'bula'))
    tipo_receita = models.ManyToManyField('produto.TipoReceita', through='produto.ProdutoTipoReceita', through_fields=('produto', 'tipo_receita'))
    principio_ativo = models.ManyToManyField('produto.PrincipioAtivo', through='produto.ProdutoPrincipioAtivo', through_fields=('produto', 'principio_ativo'))
    especialidade = models.ManyToManyField('produto.Especialidade', through='produto.ProdutoEspecialidade', through_fields=('produto', 'especialidade'))

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto'

    def __str__(self):
        return self.nome


class Tipo(core.models.Log):
    """
    :Nome da classe/função: Tipo
    :descrição: Classe de tipos de produtos possíveis
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=100, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_tipo'


class Marca(core.models.Log):
    """
    :Nome da classe/função: Marca
    :descrição: Classe de marcas de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    descricao = models.CharField(max_length=500, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)
    nm_ecommerce = models.CharField(max_length=200, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_marca'

    def __str__(self):
        return self.nome


class ProdutoImagem(core.models.Log):
    """
    :Nome da classe/função: ProdutoImagem
    :descrição: Classe de relação entre imagens e produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    imagem = models.FileField(upload_to="produtos", default='produtos/caixa-nissei.jpg', null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_imagem'


class Grupo(core.models.Log):
    """
    :Nome da classe/função: Grupo
    :descrição: Classe de grupos de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    descricao = models.CharField(max_length=500, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_grupo'


class ProdutoGrupo(core.models.Log):
    """
    :Nome da classe/função: ProdutoGrupo
    :descrição: Classe de relação entre produtos e grupos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    grupo = models.ForeignKey('produto.Grupo', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtogrupo'


class Categoria(core.models.Log):
    """
    :Nome da classe/função: Categoria
    :descrição: Classe de categorias de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    categoria_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_categoria'


class ProdutoCategoria(core.models.Log):
    """
    :Nome da classe/função: ProdutoCategoria
    :descrição: Classe de relação entre produtos e categorias
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    categoria = models.ForeignKey('produto.Categoria', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtocategoria'


class Kit(core.models.Log):
    """
    :Nome da classe/função: Kit
    :descrição: Classe de kits de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_kit'


class ProdutoKit(core.models.Log):
    """
    :Nome da classe/função: ProdutoKit
    :descrição: Classe de relação entre produtos e kits
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    kit = models.ForeignKey('produto.Kit', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtokit'


class Bula(core.models.Log):
    """
    :Nome da classe/função: Bula
    :descrição: Classe de bulas de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_bula'


class ProdutoBula(core.models.Log):
    """
    :Nome da classe/função: ProdutoBula
    :descrição: Classe de relação entre produtos e bulas
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    bula = models.ForeignKey('produto.Bula', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtobula'


class TipoReceita(core.models.Log):
    """
    :Nome da classe/função: TipoReceita
    :descrição: Classe de tipos de receitas
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_tiporeceita'


class ProdutoTipoReceita(core.models.Log):
    """
    :Nome da classe/função: ProdutoBula
    :descrição: Classe de relação entre produtos e tipos de receitas
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    tipo_receita = models.ForeignKey('produto.TipoReceita', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtotiporeceita'


class PrincipioAtivo(core.models.Log):
    """
    :Nome da classe/função: PrincipioAtivo
    :descrição: Classe de principios ativos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_principioativo'


class ProdutoPrincipioAtivo(core.models.Log):
    """
    :Nome da classe/função: ProdutoBula
    :descrição: Classe de relação entre produtos e principio ativos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    principio_ativo = models.ForeignKey('produto.PrincipioAtivo', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtoprincipioativo'


class Especialidade(core.models.Log):
    """
    :Nome da classe/função: Especialidade
    :descrição: Classe de especialidade de produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    nm_url_ecommerce = models.SlugField(max_length=100, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_especialidade'


class ProdutoEspecialidade(core.models.Log):
    """
    :Nome da classe/função: ProdutoEspecialidade
    :descrição: Classe de relação entre produtos e especialidades
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    especialidade = models.ForeignKey('produto.Especialidade', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_produtoespecialidade'


class ProdutoEan(core.models.Log):
    """
    :Nome da classe/função: ProdutoEan
    :descrição: Classe de relação entre produtos e EANs
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    ean = models.CharField(max_length=50, primary_key=True)
    is_principal = models.BooleanField(default=True, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_ean'


class PrecoLista(core.models.Log):
    """
    :Nome da classe/função: PrecoLista
    :descrição: Classe de lista de preços para referência de preços dos produtos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=200, null=True, blank=True)
    dat_ini = models.DateField(null=True, blank=True)
    dat_fim = models.DateField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'preco_lista'

    def __str__(self):
        return self.nome


class ProdutoPreco(core.models.Log):
    """
    :Nome da classe/função: PrecoLista
    :descrição: Classe de relação entre produto e preço
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    valor = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)

    precolista = models.ForeignKey('produto.PrecoLista', on_delete=models.DO_NOTHING, null=True, blank=True)
    desconto = models.ManyToManyField('produto.Desconto', through='produto.DescontoProdutoPreco', through_fields=('produtopreco', 'desconto'))

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_preco'


class TipoDesconto(core.models.Log):
    """
    :Nome da classe/função: TipoDesconto
    :descrição: Classe de tipos de descontos existentes
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    nome = models.CharField(max_length=100, primary_key=True)
    descricao = models.CharField(max_length=200, null=True, blank=True)
    tipo = models.CharField(max_length=10, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_tipodesconto'


class Desconto(core.models.Log):
    """
    :Nome da classe/função: Desconto
    :descrição: Classe de descontos
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    tipo = models.ForeignKey('produto.TipoDesconto', on_delete=models.DO_NOTHING, null=True, blank=True)
    qtd_ini_desc = models.IntegerField(null=True, blank=True)
    qtd_fim_desc = models.IntegerField(null=True, blank=True)
    valor_desc = models.DecimalField(max_digits=14, decimal_places=2, null=True, blank=True)
    per_desc = models.DecimalField(max_digits=10, decimal_places=2, null=True, blank=True)
    dat_ini = models.DateField(null=True, blank=True)
    dat_fim = models.DateField(null=True, blank=True)

    prioridade = models.IntegerField(null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_desconto'


class DescontoProdutoPreco(core.models.Log):
    """
    :Nome da classe/função: DescontoProdutoPreco
    :descrição: Classe de relação entre desconto e produtopreco
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    desconto = models.ForeignKey('produto.Desconto', on_delete=models.DO_NOTHING, null=True, blank=True)
    produtopreco = models.ForeignKey('produto.ProdutoPreco', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_descontoprodutopreco'


class Estoque(core.models.Log):
    """
    :Nome da classe/função: Estoque
    :descrição: Classe de estoque
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    produto = models.ForeignKey('produto.Produto', on_delete=models.DO_NOTHING, null=True, blank=True)
    quantidade = models.IntegerField(null=True, blank=True)
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True, blank=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'produto_estoque'


import unicodedata

import requests
import json
from django.apps import apps


class Integracao:
    """
    :Nome da classe/função: Integracao
    :descrição: Classe para integrações
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    def __init__(self, url=None, body=None, headers=None, servico=None, request=None, modulo=None):
        self.url = url
        self.body = body
        self.headers = headers
        self.response = None
        self.servico = servico
        self.status_code = None
        self.tipo = None
        self.request = request
        self.modulo = modulo

    def salvar(self):
        """
        :Nome da classe/função: salvar
        :descrição: Função para salvar log das integrações
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return: Status de salvar
        """
        try:
            nome_modulo = self.modulo.lower() if self.modulo is not None else 'venda_mais'
            if nome_modulo == 'cliente':
                log_model = apps.get_model('log', 'ClienteIntegracao')
            elif nome_modulo == 'venda_mais':
                log_model = apps.get_model('log', 'Venda_maisIntegracao')
            elif nome_modulo == 'indicador':
                log_model = apps.get_model('log', 'IndicadorIntegracao')
            elif nome_modulo == 'fornecedor':
                log_model = apps.get_model('log', 'FornecedorIntegracao')
            elif nome_modulo == 'processos':
                log_model = apps.get_model('log', 'ProcessosIntegracao')
            else:
                return False

            nova_integracao = log_model(
                servico=self.servico,
                url=self.url,
                body=self.body,
                headers=self.headers,
                response=self.response,
                status_code=self.status_code,
                tipo=self.tipo
            )
            nova_integracao.save(request_=self.request)
            return True
        except:
            return False

    def tratar_campo(self, campo=None):
        """
        :Nome da classe/função: tratar_campo
        :descrição: Função para tratar o campos para enviar para integração
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :param campo: Valor a ser tratado
        :return: Valor tratado
        """
        if isinstance(campo, str) and campo is not None:
            campo = unicodedata.normalize('NFD', campo)
        return campo if campo is not None else ''

    def post(self):
        """
        :Nome da classe/função: post
        :descrição: Função para enviar uma requisição POST
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return:
        """
        data = json.dumps(self.body, ensure_ascii=False)
        data = unicodedata.normalize('NFD', data).encode('ASCII', 'ignore')
        resposta = requests.post(self.url, data=data, headers=self.headers)
        self.response = resposta.content
        self.status_code = resposta.status_code
        self.salvar()

    def get(self):
        """
        :Nome da classe/função: get
        :descrição: Função para enviar uma requisição GET
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :return:
        """
        resposta = requests.get(self.url, headers=self.headers, data=self.body)
        self.response = resposta.content
        self.status_code = resposta.status_code
        self.salvar()

    @property
    def url(self):
        return self.__url

    @url.setter
    def url(self, value):
        self.__url = value

    @url.deleter
    def url(self):
        del self.__url

    @property
    def body(self):
        return self.__body

    @body.setter
    def body(self, value):
        self.__body = value if value is not None else {}

    @body.deleter
    def body(self):
        del self.__body

    @property
    def headers(self):
        return self.__headers

    @headers.setter
    def headers(self, value):
        self.__headers = value if value is not None else {'Content-type': 'application/json'}

    @headers.deleter
    def headers(self):
        del self.__headers

    @property
    def response(self):
        return self.__response

    @response.setter
    def response(self, value):
        self.__response = value

    @response.deleter
    def response(self):
        del self.__response

    @property
    def servico(self):
        return self.__servico

    @servico.setter
    def servico(self, value):
        self.__servico = value

    @servico.deleter
    def servico(self):
        del self.__servico

    @property
    def status_code(self):
        return self.__status_code

    @status_code.setter
    def status_code(self, value):
        self.__status_code = value

    @status_code.deleter
    def status_code(self):
        del self.__status_code

    @property
    def tipo(self):
        return self.__tipo

    @tipo.setter
    def tipo(self, value):
        self.__tipo = value

    @tipo.deleter
    def tipo(self):
        del self.__tipo

    @property
    def request(self):
        return self.__request

    @request.setter
    def request(self, value):
        self.__request = value

    @request.deleter
    def request(self):
        del self.__request

    @property
    def modulo(self):
        return self.__modulo

    @modulo.setter
    def modulo(self, value):
        self.__modulo = value

    @modulo.deleter
    def modulo(self):
        del self.__modulo


from compositefk.fields import CompositeForeignKey
from django.db import models
import core.models
# Create your models here.


class Filial(core.models.Log, core.models.EmpresaLog, core.models.EnderecoComplementoLog, core.models.ContatoLog):
    """
    :Nome da classe/função: Filial
    :descrição: Classe de filiais e suas informações principais
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    --- 18/08/2020 - Nícolas Marinoni Grande
    - Motivo: Inserção dos campos ip_acesso, area, areas, dat_abertura, dat_fechamento, is_loja, e hierarquia da tabela de ContatoLog. Remoção do campo telefone.

    """
    cd_filial = models.IntegerField(primary_key=True)
    nome = models.CharField(max_length=200, null=True)
    nome_completo = models.CharField(max_length=200, null=True)
    cnpj = models.CharField(max_length=50, null=True)

    ip_acesso = models.CharField(max_length=100, null=True)
    area = models.ForeignKey('filial.Area', on_delete=models.DO_NOTHING, null=True, related_name='area_atual')

    servicos = models.ManyToManyField('filial.Servico', through='FilialServico', through_fields=('cd_filial', 'servico'))

    dat_abertura = models.DateField(null=True)
    dat_fechamento = models.DateField(null=True)
    is_loja = models.BooleanField(null=True, default=True)

    areas = models.ManyToManyField('filial.Area', through='FilialArea', through_fields=('cd_filial', 'area'))

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial'

    def __str__(self):
        return self.nome


class Area(core.models.Log):
    """
    :Nome da classe/função: Area
    :descrição: Classe de áreas genéricas da filial
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    cd_area = models.IntegerField(primary_key=True)
    nome = models.CharField(max_length=200, null=True)
    nome_completo = models.CharField(max_length=200, null=True)
    responsavel = models.ForeignKey('funcionario.Funcionario', on_delete=models.DO_NOTHING, null=True)
    area_pai = models.ForeignKey('self', on_delete=models.DO_NOTHING, null=True)

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='FILIAL.AREA')
    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='filial_area', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_area'

    def __str__(self):
        return self.nome


class FilialArea(core.models.Log):
    """
    :Nome da classe/função: FilialArea
    :descrição: Classe de relação história entre filial e área
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    area = models.ForeignKey('filial.Area', on_delete=models.DO_NOTHING, null=True)
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)
    responsavel = models.ForeignKey('funcionario.Funcionario', on_delete=models.DO_NOTHING, null=True)

    dat_ini = models.DateField(null=True)
    dat_fim = models.DateField(null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_filialarea'


class Servico(core.models.Log):
    """
    :Nome da classe/função: Servico
    :descrição: Classe de serviços possíveis que uma filial pode ofertar
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
     --- 18/08/2020 - Nícolas Marinoni Grande
    - Motivo: Alteração do campo Id para nome
    """
    nome = models.CharField(max_length=200, primary_key=True)
    nm_descritivo = models.CharField(max_length=200, null=True)
    descricao = models.TextField(null=True)

    tipo_codigo = models.CharField(null=True, max_length=200)
    tipo_tipo = models.CharField(null=True, max_length=200, default='FILIAL.SERVICO')
    tipo = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='filial_servico_tipo', to_fields={
        "codigo": "tipo_codigo",
        "tipo": "tipo_tipo"
    })

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_servico'

    def __str__(self):
        return self.nome


class FilialServico(core.models.Log):
    """
    :Nome da classe/função: FilialServico
    :descrição: Classe de relação de filial com serviços
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    --- 18/08/2020 - Nícolas Marinoni Grande
    - Motivo: Inserção do campo informacoes
    """
    servico = models.ForeignKey('filial.Servico', on_delete=models.DO_NOTHING, null=True)
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)

    informacao = models.CharField(max_length=500, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_filialservico'


class FilialHoraFuncionamento(core.models.Log):
    """
    :Nome da classe/função: FilialHoraFuncionamento
    :descrição: Classe de relação de filial com o seu horário de funcionamento
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    is_padrao = models.BooleanField(null=True, default=True)
    dat_ini_validade = models.DateField(null=True)
    dat_fim_validade = models.DateTimeField(null=True)

    cd_hr_util_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_util_inicio")
    cd_hr_util_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_util_fim")
    cd_hr_sab_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_sab_inicio")
    cd_hr_sab_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_sab_fim")
    cd_hr_dom_inicio = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_dom_inicio")
    cd_hr_dom_fim = models.ForeignKey('core.Hora', null=True, on_delete=models.DO_NOTHING, related_name="cd_hr_dom_fim")
    cd_filial = models.ForeignKey('filial.Filial', on_delete=models.DO_NOTHING, null=True)

    class Meta(core.models.Log.Meta):
        abstract = False
        db_table = 'filial_horafuncionamento'



# Generated by Django 2.1.7 on 2020-08-24 17:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('sistema', '0010_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='perfil',
            table='sistema_perfil',
        ),
        migrations.AlterModelTable(
            name='perfilpontofuncao',
            table='sistema_perfilpontofuncao',
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-11 02:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('cliente', '0032_auto_20200809_2237'),
    ]

    operations = [
        migrations.AddField(
            model_name='cartao',
            name='pagamento_nome',
            field=models.CharField(max_length=200, null=True),
        ),
        migrations.AddField(
            model_name='cartao',
            name='password_tamanho',
            field=models.IntegerField(null=True),
        ),
    ]



# Generated by Django 2.1.7 on 2020-08-17 17:48

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('produto', '0030_auto_20200806_1830'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bula',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='categoria_pai',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='categoria',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='dat_fim',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='dat_ini',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='per_desc',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=10, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='prioridade',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='qtd_fim_desc',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='qtd_ini_desc',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='tipo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.TipoDesconto'),
        ),
        migrations.AlterField(
            model_name='desconto',
            name='valor_desc',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='desconto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Desconto'),
        ),
        migrations.AlterField(
            model_name='descontoprodutopreco',
            name='produtopreco',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.ProdutoPreco'),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='especialidade',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='cd_filial',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='filial.Filial'),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='estoque',
            name='quantidade',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='descricao',
            field=models.CharField(blank=True, max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='grupo',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='kit',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='descricao',
            field=models.CharField(blank=True, max_length=500, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nm_ecommerce',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='marca',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='dat_fim',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='dat_ini',
            field=models.DateField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='precolista',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=100, null=True),
        ),
        migrations.AlterField(
            model_name='principioativo',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='altura_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='categoria_principal',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='categoria_principal', to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='cd_externo',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='descricao',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='descricao_ecommerce',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='fabricante',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='fornecedor.Fabricante'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='imagem',
            field=models.FileField(blank=True, default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_ecommerce',
            field=models.BooleanField(blank=True, default=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_pbm',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_retencao_receita',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='is_venda_controlada',
            field=models.BooleanField(blank=True, default=False, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='largura_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='marca',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, related_name='marca', to='produto.Marca'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_ecommerce',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nm_url_ecommerce',
            field=models.SlugField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='peso_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='produto_pai',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produto',
            name='profundidade_ecommerce',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='qtd_max_venda_ecommerce',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='qtd_min_venda_ecommerce',
            field=models.IntegerField(blank=True, default=1, null=True),
        ),
        migrations.AlterField(
            model_name='produto',
            name='tipo_produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Tipo'),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='bula',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Bula'),
        ),
        migrations.AlterField(
            model_name='produtobula',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='categoria',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Categoria'),
        ),
        migrations.AlterField(
            model_name='produtocategoria',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='is_principal',
            field=models.BooleanField(blank=True, default=True, null=True),
        ),
        migrations.AlterField(
            model_name='produtoean',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='especialidade',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Especialidade'),
        ),
        migrations.AlterField(
            model_name='produtoespecialidade',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='grupo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Grupo'),
        ),
        migrations.AlterField(
            model_name='produtogrupo',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='imagem',
            field=models.FileField(blank=True, default='produtos/caixa-nissei.jpg', null=True, upload_to='produtos'),
        ),
        migrations.AlterField(
            model_name='produtoimagem',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='kit',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Kit'),
        ),
        migrations.AlterField(
            model_name='produtokit',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='precolista',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.PrecoLista'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtopreco',
            name='valor',
            field=models.DecimalField(blank=True, decimal_places=2, max_digits=14, null=True),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='principio_ativo',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.PrincipioAtivo'),
        ),
        migrations.AlterField(
            model_name='produtoprincipioativo',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='produto',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AlterField(
            model_name='produtotiporeceita',
            name='tipo_receita',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.TipoReceita'),
        ),
        migrations.AlterField(
            model_name='tipo',
            name='nm_descritivo',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='descricao',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
        migrations.AlterField(
            model_name='tipodesconto',
            name='tipo',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='tiporeceita',
            name='nome',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]



import secrets
from base64 import urlsafe_b64encode as b64e, urlsafe_b64decode as b64d

from cryptography.fernet import Fernet
from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import hashes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC

backend = default_backend()
iterations = 1_217


def _derive_key(password: bytes, salt: bytes, iterations: int = iterations) -> bytes:
    """Derive a secret key from a given password and salt"""
    kdf = PBKDF2HMAC(
        algorithm=hashes.SHA256(), length=32, salt=salt,
        iterations=iterations, backend=backend)
    return b64e(kdf.derive(password))


def password_encrypt(message: bytes, password: str, iterations: int = iterations) -> bytes:
    """
    :Nome da classe/função: Email
    :descrição: Função para criptografar senha
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    :param message: mensagem a ser criptografada
    :param password: senha usada para criptografar
    :param iterations: numero de iteracoes para criptografar
    :return: Senha criptografada
    """
    salt = secrets.token_bytes(16)
    key = _derive_key(password.encode(), salt, iterations)
    return b64e(
        b'%b%b%b' % (
            salt,
            iterations.to_bytes(4, 'big'),
            b64d(Fernet(key).encrypt(message)),
        )
    )


def password_decrypt(token: bytes, password: str) -> bytes:
    """
    :Nome da classe/função: Email
    :descrição: Função para descriptografar senha
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    :param token: Token criptografado
    :param password: Senha usada para criptografrar
    :return: senha descriptografada
    """
    decoded = b64d(token)
    salt, iter, token = decoded[:16], decoded[16:20], b64e(decoded[20:])
    iterations = int.from_bytes(iter, 'big')
    key = _derive_key(password.encode(), salt, iterations)
    return Fernet(key).decrypt(token)


# Generated by Django 2.1.7 on 2020-07-15 22:25

import compositefk.fields
from django.db import migrations, models
import django.db.models.deletion
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0003_auto_20200715_1925'),
        ('produto', '0003_auto_20200713_0030'),
    ]

    operations = [
        migrations.CreateModel(
            name='Marca',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('descricao', models.CharField(max_length=500, null=True)),
            ],
            options={
                'db_table': 'produto_marca',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='PrecoLista',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('nome', models.CharField(max_length=200, null=True)),
                ('dat_ini', models.DateField(null=True)),
                ('dat_fim', models.DateField(null=True)),
            ],
            options={
                'db_table': 'preco_lista',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoEan',
            fields=[
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('eab', models.CharField(max_length=50, primary_key=True, serialize=False)),
                ('is_principal', models.BooleanField(default=True, null=True)),
            ],
            options={
                'db_table': 'produto_ean',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.CreateModel(
            name='ProdutoImagem',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('dat_insercao', models.DateTimeField(auto_now_add=True, null=True)),
                ('dat_edicao', models.DateTimeField(auto_now=True, null=True)),
                ('dat_delete', models.DateTimeField(null=True)),
                ('usr_insercao', models.IntegerField(null=True)),
                ('usr_edicao', models.IntegerField(null=True)),
                ('usr_delete', models.IntegerField(null=True)),
                ('origem_insercao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_insercao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_edicao_codigo', models.CharField(max_length=200, null=True)),
                ('origem_edicao_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('origem_delete_codigo', models.CharField(max_length=200, null=True)),
                ('origem_delete_tipo', models.CharField(default='USR.ORIGEM', max_length=200, null=True)),
                ('status', models.BooleanField(default=True, null=True)),
                ('imagem', models.FileField(default='produtos/caixa-nissei.jpg', upload_to='produtos-imagens')),
            ],
            options={
                'db_table': 'produto_imagem',
                'abstract': False,
                'managed': True,
            },
            managers=[
                ('normal_objects', django.db.models.manager.Manager()),
            ],
        ),
        migrations.AlterModelOptions(
            name='bula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='categoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='especialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='grupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='kit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='principioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produto',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtobula',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtocategoria',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoespecialidade',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtogrupo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtokit',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtoprincipioativo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='produtotiporeceita',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tipo',
            options={'managed': True},
        ),
        migrations.AlterModelOptions(
            name='tiporeceita',
            options={'managed': True},
        ),
        migrations.AddField(
            model_name='produtoimagem',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoimagem_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoimagem',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoimagem_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoimagem',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoimagem_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoimagem',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='produtoean',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoean_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoean',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoean_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoean',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_produtoean_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='produtoean',
            name='produto',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.DO_NOTHING, to='produto.Produto'),
        ),
        migrations.AddField(
            model_name='precolista',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_precolista_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='precolista',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_precolista_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='precolista',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_precolista_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
        migrations.AddField(
            model_name='marca',
            name='origem_delete',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_marca_origem_delete', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_delete_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_delete_tipo')}),
        ),
        migrations.AddField(
            model_name='marca',
            name='origem_edicao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_marca_origem_edicao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_edicao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_edicao_tipo')}),
        ),
        migrations.AddField(
            model_name='marca',
            name='origem_insercao',
            field=compositefk.fields.CompositeForeignKey(null=True, null_if_equal=[], on_delete=django.db.models.deletion.DO_NOTHING, related_name='produto_marca_origem_insercao', to='core.Tipo', to_fields={'codigo': compositefk.fields.LocalFieldValue('origem_insercao_codigo'), 'tipo': compositefk.fields.LocalFieldValue('origem_insercao_tipo')}),
        ),
    ]



from django.http import JsonResponse
from django.views import View

from core.util.core import Inteliger


class InteligerView(View):
    """
    :Nome da classe/função: InteligerView
    :descrição: View feita para atualizar o singleton de sistema
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """
    def get(self, request, *args, **kwargs):
        """
        :Nome da classe/função: get
        :descrição: Função get que é chamada quando é feita uma requisição do tipo GET na View
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :param request: informações da requisição
        :param args:
        :param kwargs:
        :return: Json com status de sucesso
        """
        Inteliger().atualizar_tempo_query()
        return JsonResponse({'status': 'Sistema atualizado com sucesso!'}, safe=False)



from core.views import Inteliger


class LogMiddleware:
    """
    :Nome da classe/função: LogMiddleware
    :descrição: Classe de Middleware para salvar log de requisições
    :Criação: Nícolas Marinoni Grande - 17/08/2020
    :Edições:
    """

    def __init__(self, get_response):
        """
        :Nome da classe/função: __init__
        :descrição: Define a resposta ao inicializar a classe
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :param get_response: Resposta
        """
        self.get_response = get_response

    def __call__(self, request):
        """
        :Nome da classe/função: __call__
        :descrição: Salva o log ao chamar a classe
        :Criação: Nícolas Marinoni Grande - 17/08/2020
        :Edições:
        :param request:
        :return:
        """
        response = self.get_response(request)
        Inteliger().salvar_log(request=request, response=response)
        return response
